@@ -3,11 +3,11 @@ import os
 from typing import Tuple
 
 import jax.numpy as jnp
-import numpy as onp
+import numpy as np
 import pandas as pd
 
 
-def generate(path=None) -> Tuple[onp.ndarray, onp.ndarray]:
+def generate(path=None) -> Tuple[np.ndarray, np.ndarray]:
     """
     Description: Outputs the daily price of bitcoin from 2013-04-28 to 2018-02-10
     """
@@ -18,4 +18,4 @@ def generate(path=None) -> Tuple[onp.ndarray, onp.ndarray]:
 
     data = jnp.asarray(data[data.Currency == "bitcoin"].Price)
 
-    return data[:-1], data[1:]
+    return data[:-1].reshape(-1, 1), data[1:].reshape(-1, 1)
