@@ -3,13 +3,11 @@ import os
 from typing import Tuple
 
 import jax.numpy as jnp
-import numpy as onp
+import numpy as np
 import pandas as pd
 
 
-def generate(
-    input_signals=None, output_signals=None, include_month=False, path=None
-) -> Tuple[onp.ndarray, onp.ndarray]:
+def generate(input_signals=None, output_signals=None, path=None) -> Tuple[np.ndarray, np.ndarray]:
     """Generate ENSO
 
     Description: Collection of monthly values of control indices useful for predicting
@@ -45,8 +43,9 @@ def generate(
 
     # Get ONI
     data["oni"] = jnp.asarray(data.anm.rolling(3, min_periods=1).mean())
+    data["month"] = jnp.arange(signal_length) % 12
 
-    if include_month:
-        data["month"] = jnp.arange(signal_length) % 12
-
-    return jnp.asarray(data[input_signals]), jnp.asarray(data[output_signals])
+    return (
+        jnp.asarray(data[input_signals]),
+        jnp.asarray(data[output_signals]).reshape(-1, 1),
+    )
